@@ -11,7 +11,7 @@ import os
 import pwd
 from enum import Enum
 from functools import lru_cache
-from typing import Any, Dict, List, Optional, Tuple, Union
+from typing import Any, Dict, List, Optional, Tuple, TypeVar, Union
 from urllib.parse import urlparse
 
 from cached_property import cached_property
@@ -56,6 +56,9 @@ from cyberfusion.ClusterSupport.certificates import (
     Certificate,
 )
 from cyberfusion.ClusterSupport.clusters import ENDPOINT_CLUSTERS, Cluster
+from cyberfusion.ClusterSupport.clusters_cephfs_credentials import (
+    ClusterCephFSCredentials,
+)
 from cyberfusion.ClusterSupport.clusters_etcd_credentials import (
     ClusterEtcdCredentials,
 )
@@ -104,6 +107,11 @@ from cyberfusion.ClusterSupport.firewall_groups import (
     MODEL_FIREWALL_GROUPS,
     FirewallGroup,
 )
+from cyberfusion.ClusterSupport.firewall_rules import (
+    ENDPOINT_FIREWALL_RULES,
+    MODEL_FIREWALL_RULES,
+    FirewallRule,
+)
 from cyberfusion.ClusterSupport.fpm_pools import (
     ENDPOINT_FPM_POOLS,
     MODEL_FPM_POOLS,
@@ -124,6 +132,11 @@ from cyberfusion.ClusterSupport.haproxy_listens_to_nodes import (
     MODEL_HAPROXY_LISTENS_TO_NODES,
     HAProxyListenToNode,
 )
+from cyberfusion.ClusterSupport.hosts_entries import (
+    ENDPOINT_HOSTS_ENTRIES,
+    MODEL_HOSTS_ENTRIES,
+    HostsEntry,
+)
 from cyberfusion.ClusterSupport.htpasswd_files import (
     ENDPOINT_HTPASSWD_FILES,
     MODEL_HTPASSWD_FILES,
@@ -214,6 +227,11 @@ from cyberfusion.ClusterSupport.service_accounts_to_customers import (
     ENDPOINT_SERVICE_ACCOUNTS_TO_CUSTOMERS,
     ServiceAccountToCustomer,
 )
+from cyberfusion.ClusterSupport.sites import ENDPOINT_SITES, MODEL_SITES, Site
+from cyberfusion.ClusterSupport.sites_to_customers import (
+    ENDPOINT_SITES_TO_CUSTOMERS,
+    SiteToCustomer,
+)
 from cyberfusion.ClusterSupport.ssh_keys import (
     ENDPOINT_SSH_KEYS,
     MODEL_SSH_KEYS,
@@ -269,6 +287,11 @@ ENDPOINTS_USAGES = [
 ]
 ENDPOINTS_LOGS = [ENDPOINT_ERROR_LOGS, ENDPOINT_ACCESS_LOGS]
 
+# Sentinel value to load all objects when `clusterid` is set in config file, which
+# is used when `cluster_ids` is None. An instance of `object` is truthy.
+
+ALL_CLUSTERS = TypeVar("ALL_CLUSTERS")
+
 
 class SortOrder(str, Enum):
     """Sort orders."""
@@ -320,6 +343,7 @@ class ClusterSupport:
     GROUP_NODE_LIBREOFFICE = "LibreOffice"
     GROUP_NODE_GHOSTSCRIPT = "Ghostscript"
     GROUP_NODE_FFMPEG = "FFmpeg"
+    GROUP_NODE_DOCKER = "Docker"
     GROUP_NODE_MALDET = "maldet"
 
     GROUP_CLUSTER_WEB = "Web"
@@ -337,7 +361,7 @@ class ClusterSupport:
         self,
         *,
         config_file_path: Optional[str] = None,
-        cluster_ids: Optional[List[int]] = None,
+        cluster_ids: Optional[Union[List[int], ALL_CLUSTERS]] = None,
     ) -> None:
         """Prepare by setting attributes and calling function to set objects.
 
@@ -585,6 +609,11 @@ class ClusterSupport:
         """Get object(s) from API."""
         return self._get_objects(FPMPool, ENDPOINT_FPM_POOLS, MODEL_FPM_POOLS)
 
+    @cached_property
+    def sites(self) -> List[Site]:
+        """Get object(s) from API."""
+        return self._get_objects(Site, ENDPOINT_SITES, MODEL_SITES)
+
     @cached_property
     def customers(self) -> List[Customer]:
         """Get object(s) from API."""
@@ -606,6 +635,13 @@ class ClusterSupport:
             FirewallGroup, ENDPOINT_FIREWALL_GROUPS, MODEL_FIREWALL_GROUPS
         )
 
+    @cached_property
+    def firewall_rules(self) -> List[CustomConfigSnippet]:
+        """Get object(s) from API."""
+        return self._get_objects(
+            FirewallRule, ENDPOINT_FIREWALL_RULES, MODEL_FIREWALL_RULES
+        )
+
     @cached_property
     def tombstones(self) -> List[Tombstone]:
         """Get object(s) from API."""
@@ -656,6 +692,13 @@ class ClusterSupport:
         """Get object(s) from API."""
         return self._get_objects(Cron, ENDPOINT_CRONS, MODEL_CRONS)
 
+    @cached_property
+    def hosts_entries(self) -> List[HostsEntry]:
+        """Get object(s) from API."""
+        return self._get_objects(
+            HostsEntry, ENDPOINT_HOSTS_ENTRIES, MODEL_HOSTS_ENTRIES
+        )
+
     @cached_property
     def security_txt_policies(self) -> List[SecurityTXTPolicy]:
         """Get object(s) from API."""
@@ -800,6 +843,11 @@ class ClusterSupport:
             ENDPOINT_SERVICE_ACCOUNTS_TO_CLUSTERS,
         )
 
+    @cached_property
+    def sites_to_customers(self) -> List[ServiceAccountToCluster]:
+        """Get object(s) from API."""
+        return self._get_objects(SiteToCustomer, ENDPOINT_SITES_TO_CUSTOMERS)
+
     @cached_property
     def service_accounts_to_customers(self) -> List[ServiceAccountToCustomer]:
         """Get object(s) from API."""
@@ -839,6 +887,16 @@ class ClusterSupport:
             ENDPOINT_CLUSTERS + f"/{cluster_id}" + "/rabbitmq-credentials",
         )
 
+    @lru_cache(maxsize=None)
+    def cluster_cephfs_credentials(
+        self, cluster_id: int
+    ) -> ClusterCephFSCredentials:
+        """Get object(s) from API."""
+        return self._get_object(
+            ClusterCephFSCredentials,
+            ENDPOINT_CLUSTERS + f"/{cluster_id}" + "/cephfs-credentials",
+        )
+
     @lru_cache(maxsize=None)
     def cluster_etcd_credentials(
         self, cluster_id: int
@@ -958,7 +1016,7 @@ class ClusterSupport:
         a certain cluster ID.
         """
 
-        # If cluster IDs areq not set, we want objects for all clusters
+        # If cluster IDs are not set, we want objects for all clusters
 
         if not self.cluster_ids:
             return True
@@ -980,21 +1038,22 @@ class ClusterSupport:
         return CyberfusionConfig(path=self._config_file_path)
 
     @cached_property
-    def cluster_ids(self) -> List[int]:
+    def cluster_ids(self) -> Optional[List[int]]:
         """Get cluster IDs.
 
-        Cluster IDs are determined in this order:
-
-        - Preset, if set
-        - From the config, if present
-        - By service accounts to clusters, if service account ID is set
-        - None
+        See README for ordering.
         """
+        if self._preset_cluster_ids is ALL_CLUSTERS:
+            return None
 
         # Use preset cluster IDs if set
 
-        if self._preset_cluster_ids:
-            return self._preset_cluster_ids
+        if self._preset_cluster_ids is not None:
+            # At this time, we know self._preset_cluster_ids is not ALL_CLUSTERS
+            # (early return above) and it is not None. Given its type of Optional[Union[List[int], ALL_CLUSTERS]],
+            # that means it can only be a list. However, mypy does not understand this.
+
+            return self._preset_cluster_ids  # type: ignore[return-value]
 
         # Set cluster IDs from config
 
@@ -1007,7 +1066,7 @@ class ClusterSupport:
                 )
             ]
         except configparser.NoOptionError:
-            # Non node clients may not have cluster IDs
+            # Non node clients may not have cluster ID
 
             pass
 
@@ -1022,7 +1081,7 @@ class ClusterSupport:
                 if object_["service_account_id"] == self.service_account_id
             ]
 
-        return []
+        return None
 
     @cached_property
     def username(self) -> str:
@@ -1074,6 +1133,9 @@ class ClusterSupport:
 
     def _check_cluster_ids(self) -> None:
         """Check if API user can access the selected clusters."""
+        if not self.cluster_ids:
+            return
+
         for cluster_id in self.cluster_ids:
             if cluster_id in self._accessible_cluster_api_clusters:
                 continue
@@ -1238,6 +1300,10 @@ class ClusterSupport:
         """Get object from loaded objects."""
         return self._filter_objects(self.fpm_pools, **kwargs)
 
+    def get_sites(self, **kwargs: Any) -> List[Site]:
+        """Get object from loaded objects."""
+        return self._filter_objects(self.sites, **kwargs)
+
     def get_customers(self, **kwargs: Any) -> List[Customer]:
         """Get object from loaded objects."""
         return self._filter_objects(self.customers, **kwargs)
@@ -1252,6 +1318,10 @@ class ClusterSupport:
         """Get object from loaded objects."""
         return self._filter_objects(self.firewall_groups, **kwargs)
 
+    def get_firewall_rules(self, **kwargs: Any) -> List[FirewallRule]:
+        """Get object from loaded objects."""
+        return self._filter_objects(self.firewall_rules, **kwargs)
+
     def get_tombstones(self, **kwargs: Any) -> List[Tombstone]:
         """Get object from loaded objects."""
         return self._filter_objects(self.tombstones, **kwargs)
@@ -1296,6 +1366,10 @@ class ClusterSupport:
         """Get object from loaded objects."""
         return self._filter_objects(self.crons, **kwargs)
 
+    def get_hosts_entries(self, **kwargs: Any) -> List[HostsEntry]:
+        """Get object from loaded objects."""
+        return self._filter_objects(self.hosts_entries, **kwargs)
+
     def get_security_txt_policies(
         self, **kwargs: Any
     ) -> List[SecurityTXTPolicy]:
@@ -1372,6 +1446,10 @@ class ClusterSupport:
         """Get object from loaded objects."""
         return self._filter_objects(self.service_account_servers, **kwargs)
 
+    def get_sites_to_customers(self, **kwargs: Any) -> List[SiteToCustomer]:
+        """Get object from loaded objects."""
+        return self._filter_objects(self.sites_to_customers, **kwargs)
+
     def get_service_accounts_to_clusters(
         self, **kwargs: Any
     ) -> List[ServiceAccountToCluster]:
