@@ -20,6 +20,8 @@ class APIKey(APIObjectInterface):
         """Set class attributes from API output."""
         self.id = obj["id"]
         self.hashed_key = obj["hashed_key"]
+        self.object_id = obj["object_id"]
+        self.object_model_name = obj["object_model_name"]
         self.api_user_id = obj["api_user_id"]
         self.created_at = obj["created_at"]
         self.updated_at = obj["updated_at"]
