@@ -9,6 +9,7 @@ from cyberfusion.ClusterSupport._interfaces import (
     sort_lists,
 )
 from cyberfusion.ClusterSupport.nodes import NodeGroup
+from cyberfusion.ClusterSupport.task_collections import TaskCollection
 
 ENDPOINT_CLUSTERS = "clusters"
 
@@ -89,6 +90,7 @@ class Cluster(APIObjectInterface):
         "Groups",
         "PHP Versions",
         "NodeJS Versions",
+        "Site",
     ]
     _TABLE_HEADERS_DETAILED = [
         "UNIX Users\nHome Directory",
@@ -98,6 +100,7 @@ class Cluster(APIObjectInterface):
         "Malware Toolkit\nScans",
         "Bubblewrap\nToolkit",
         "Automatic\nUpgrades",
+        "Firewall Rules\nExternal Providers",
     ]
 
     _TABLE_FIELDS = [
@@ -107,6 +110,7 @@ class Cluster(APIObjectInterface):
         "groups",
         "php_versions",
         "nodejs_versions",
+        "_site_name",
     ]
     _TABLE_FIELDS_DETAILED = [
         "unix_users_home_directory",
@@ -116,6 +120,7 @@ class Cluster(APIObjectInterface):
         "malware_toolkit_scans_enabled",
         "bubblewrap_toolkit_enabled",
         "automatic_upgrades_enabled",
+        "firewall_rules_external_providers_enabled",
     ]
 
     @sort_lists  # type: ignore[misc]
@@ -164,13 +169,20 @@ class Cluster(APIObjectInterface):
         ]
         self.bubblewrap_toolkit_enabled = obj["bubblewrap_toolkit_enabled"]
         self.automatic_upgrades_enabled = obj["automatic_upgrades_enabled"]
+        self.firewall_rules_external_providers_enabled = obj[
+            "firewall_rules_external_providers_enabled"
+        ]
         self.sync_toolkit_enabled = obj["sync_toolkit_enabled"]
         self.customer_id = obj["customer_id"]
         self.kernelcare_license_key = obj["kernelcare_license_key"]
         self.description = obj["description"]
+        self.site_id = obj["site_id"]
         self.created_at = obj["created_at"]
         self.updated_at = obj["updated_at"]
 
+        self.site = self.support.get_sites(id_=self.site_id)[0]
+        self._site_name = self.site.name
+
         if self.unix_users_home_directory:
             self.php_sessions_directory = os.path.join(
                 self.unix_users_home_directory, "sessions"
@@ -246,10 +258,12 @@ class Cluster(APIObjectInterface):
         sync_toolkit_enabled: bool,
         bubblewrap_toolkit_enabled: bool,
         automatic_upgrades_enabled: bool,
+        firewall_rules_external_providers_enabled: bool,
         malware_toolkit_scans_enabled: bool,
         database_toolkit_enabled: bool,
         description: str,
-    ) -> None:
+        site_id: int,
+    ) -> TaskCollection:
         """Create object."""
         url = f"/api/v1/{ENDPOINT_CLUSTERS}"
         data = {
@@ -284,18 +298,35 @@ class Cluster(APIObjectInterface):
             "sync_toolkit_enabled": sync_toolkit_enabled,
             "bubblewrap_toolkit_enabled": bubblewrap_toolkit_enabled,
             "automatic_upgrades_enabled": automatic_upgrades_enabled,
+            "firewall_rules_external_providers_enabled": firewall_rules_external_providers_enabled,
             "malware_toolkit_scans_enabled": malware_toolkit_scans_enabled,
             "database_toolkit_enabled": database_toolkit_enabled,
             "description": description,
+            "site_id": site_id,
         }
 
+        # Create object and create and set attributes on TaskCollection
+        # class
+
         self.support.request.POST(url, data)
         response = self.support.request.execute()
 
+        obj = TaskCollection(self.support)
+        obj._set_attributes_from_model(response)
+
+        # Get object and set attributes on local class
+
+        url = f"/api/v1/{ENDPOINT_CLUSTERS}/{obj.object_id}"
+
+        self.support.request.GET(url)
+        response = self.support.request.execute()
+
         self._set_attributes_from_model(response)
 
         self.support.clusters.append(self)
 
+        return obj
+
     def update(self) -> None:
         """Update object."""
         url = f"/api/v1/{ENDPOINT_CLUSTERS}/{self.id}"
@@ -333,9 +364,11 @@ class Cluster(APIObjectInterface):
             "sync_toolkit_enabled": self.sync_toolkit_enabled,
             "bubblewrap_toolkit_enabled": self.bubblewrap_toolkit_enabled,
             "automatic_upgrades_enabled": self.automatic_upgrades_enabled,
+            "firewall_rules_external_providers_enabled": self.firewall_rules_external_providers_enabled,
             "malware_toolkit_scans_enabled": self.malware_toolkit_scans_enabled,
             "database_toolkit_enabled": self.database_toolkit_enabled,
             "description": self.description,
+            "site_id": self.site_id,
         }
 
         self.support.request.PUT(url, data)
@@ -376,3 +409,43 @@ class Cluster(APIObjectInterface):
         self.support.request.GET(url)
 
         return self.support.request.execute()
+
+    def create_ip_address(
+        self, *, service_account_name: str, dns_name: str, address_family: str
+    ) -> TaskCollection:
+        """Create IP address."""
+        url = f"/api/v1/{ENDPOINT_CLUSTERS}/{self.id}/ip-addresses"
+        data = {
+            "service_account_name": service_account_name,
+            "dns_name": dns_name,
+            "address_family": address_family,
+        }
+
+        self.support.request.POST(url, data)
+        response = self.support.request.execute()
+
+        obj = TaskCollection(self.support)
+        obj._set_attributes_from_model(response)
+
+        return obj
+
+    def delete_ip_address(self, id_: int) -> TaskCollection:
+        """Delete IP address."""
+        url = f"/api/v1/{ENDPOINT_CLUSTERS}/{self.id}/ip-addresses/{id_}"
+
+        self.support.request.DELETE(url)
+        response = self.support.request.execute()
+
+        obj = TaskCollection(self.support)
+        obj._set_attributes_from_model(response)
+
+        return obj
+
+    def get_ip_address_products(self) -> dict:
+        """Get IP address products."""
+        url = f"/api/v1/{ENDPOINT_CLUSTERS}/ip-addresses/products"
+
+        self.support.request.GET(url)
+        response = self.support.request.execute()
+
+        return response
