@@ -25,18 +25,10 @@ class Customer(APIObjectInterface):
         self.is_internal = obj["is_internal"]
         self.identifier = obj["identifier"]
         self.dns_subdomain = obj["dns_subdomain"]
-        self.netbox_default_prefix_ipv4_id = obj[
-            "netbox_default_prefix_ipv4_id"
-        ]
-        self.netbox_default_prefix_ipv6_id = obj[
-            "netbox_default_prefix_ipv6_id"
-        ]
-        self.netbox_default_vlan_id = obj["netbox_default_vlan_id"]
-        self.netbox_vlan_ids = obj["netbox_vlan_ids"]
         self.created_at = obj["created_at"]
         self.updated_at = obj["updated_at"]
 
-    def create(self, *, team_code: str, is_internal: bool) -> TaskCollection:
+    def create(self, *, team_code: str, is_internal: bool) -> None:
         """Create object."""
         url = f"/api/v1/{ENDPOINT_CUSTOMERS}"
         data = {"team_code": team_code, "is_internal": is_internal}
@@ -44,15 +36,62 @@ class Customer(APIObjectInterface):
         self.support.request.POST(url, data)
         response = self.support.request.execute()
 
+        self._set_attributes_from_model(response)
+
+        self.support.customers.append(self)
+
+    def get_ip_addresses(self) -> dict[str, Any]:
+        """Get IP addresses."""
+        url = f"/api/v1/{ENDPOINT_CUSTOMERS}/{self.id}/ip-addresses"
+
+        self.support.request.GET(url)
+
+        return self.support.request.execute()
+
+    def get_customer_network_configurations(self) -> dict[str, Any]:
+        """Get network configurations."""
+        url = f"/api/v1/{ENDPOINT_CUSTOMERS}/{self.id}/network-configurations"
+
+        self.support.request.GET(url)
+
+        return self.support.request.execute()
+
+    def create_ip_address(
+        self, *, service_account_name: str, dns_name: str, address_family: str
+    ) -> TaskCollection:
+        """Create IP address."""
+        url = f"/api/v1/{ENDPOINT_CUSTOMERS}/{self.id}/ip-addresses"
+        data = {
+            "service_account_name": service_account_name,
+            "dns_name": dns_name,
+            "address_family": address_family,
+        }
+
+        self.support.request.POST(url, data)
+        response = self.support.request.execute()
+
         obj = TaskCollection(self.support)
         obj._set_attributes_from_model(response)
 
         return obj
 
-    def get_ip_addresses(self) -> dict[str, Any]:
-        """Get IP addresses."""
-        url = f"/api/v1/{ENDPOINT_CUSTOMERS}/{self.id}/ip-addresses"
+    def delete_ip_address(self, id_: int) -> TaskCollection:
+        """Delete IP address."""
+        url = f"/api/v1/{ENDPOINT_CUSTOMERS}/{self.id}/ip-addresses/{id_}"
+
+        self.support.request.DELETE(url)
+        response = self.support.request.execute()
+
+        obj = TaskCollection(self.support)
+        obj._set_attributes_from_model(response)
+
+        return obj
+
+    def get_ip_address_products(self) -> dict:
+        """Get IP address products."""
+        url = f"/api/v1/{ENDPOINT_CUSTOMERS}/ip-addresses/products"
 
         self.support.request.GET(url)
+        response = self.support.request.execute()
 
-        return self.support.request.execute()
+        return response
