@@ -19,6 +19,7 @@ class ObjectModelName(str, Enum):
     CERTIFICATE_MANAGER: str = "CertificateManager"
     BASIC_AUTHENTICATION_REALM: str = "BasicAuthenticationRealm"
     CRON: str = "Cron"
+    HOSTS_ENTRY: str = "HostsEntry"
     DATABASE_USER: str = "DatabaseUser"
     DATABASE_USER_GRANT: str = "DatabaseUserGrant"
     HTPASSWD_FILE: str = "HtpasswdFile"
@@ -40,3 +41,13 @@ class ObjectModelName(str, Enum):
     HAPROXY_LISTEN_TO_NODE: str = "HAProxyListenToNode"
     URL_REDIRECT: str = "URLRedirect"
     CUSTOMER: str = "Customer"
+    IP_ADDRESS: str = "IPAddress"
+    SITE: str = "Site"
+    SITE_TO_CUSTOMER: str = "SiteToCustomer"
+
+
+class IPAddressFamily(str, Enum):
+    """IP address families."""
+
+    IPV6: str = "IPv6"
+    IPV4: str = "IPv4"
