@@ -44,6 +44,7 @@ class NodeGroup(str, Enum):
     LIBREOFFICE: str = "LibreOffice"
     GHOSTSCRIPT: str = "Ghostscript"
     FFMPEG: str = "FFmpeg"
+    DOCKER: str = "Docker"
     MALDET: str = "maldet"
 
 
@@ -118,7 +119,7 @@ class Node(APIObjectInterface):
             "product": product,
         }
 
-        # Create node object and create and set attributes on TaskCollection
+        # Create object and create and set attributes on TaskCollection
         # class
 
         self.support.request.POST(url, data)
@@ -127,7 +128,7 @@ class Node(APIObjectInterface):
         obj = TaskCollection(self.support)
         obj._set_attributes_from_model(response)
 
-        # Get node object and set attributes on local class
+        # Get object and set attributes on local class
 
         url = f"/api/v1/{ENDPOINT_NODES}/{obj.object_id}"
 
@@ -197,10 +198,35 @@ class Node(APIObjectInterface):
             raise
 
     def get_products(self) -> dict:
-        """Get node ad-on products."""
+        """Get node add-on products."""
         url = f"/api/v1/{ENDPOINT_NODES}/{self.id}/products"
 
         self.support.request.GET(url)
         response = self.support.request.execute()
 
         return response
+
+    def get_ip_addresses(self) -> dict:
+        """Get node IP addresses."""
+        url = f"/api/v1/{ENDPOINT_NODES}/{self.id}/ip-addresses"
+
+        self.support.request.GET(url)
+        response = self.support.request.execute()
+
+        return response
+
+    def xgrade(self, product: str) -> TaskCollection:
+        """Xgrade node."""
+        url = f"/api/v1/{ENDPOINT_NODES}/{self.id}/xgrade"
+        data: dict = {}
+        params = {
+            "product": product,
+        }
+
+        self.support.request.POST(url, data, params)
+        response = self.support.request.execute()
+
+        obj = TaskCollection(self.support)
+        obj._set_attributes_from_model(response)
+
+        return obj
