@@ -35,6 +35,7 @@ class ServiceAccount(APIObjectInterface):
         self.id = obj["id"]
         self.name = obj["name"]
         self.group = obj["group"]
+        self.site_id = obj["site_id"]
         self.default_ipv6_ip_address = obj["default_ipv6_ip_address"]
         self.default_ipv4_ip_address = obj["default_ipv4_ip_address"]
         self.default_ipv6_netbox_id = obj["default_ipv6_netbox_id"]
@@ -50,11 +51,14 @@ class ServiceAccount(APIObjectInterface):
         self.created_at = obj["created_at"]
         self.updated_at = obj["updated_at"]
 
+        self.site = self.support.get_sites(id_=self.site_id)[0]
+
     def create(
         self,
         *,
         name: str,
         group: ServiceAccountGroup,
+        site_id: int,
         default_ipv6_ip_address: Optional[str],
         default_ipv4_ip_address: Optional[str],
         default_ipv6_netbox_id: Optional[str],
@@ -69,6 +73,7 @@ class ServiceAccount(APIObjectInterface):
         data = {
             "name": name,
             "group": group,
+            "site_id": site_id,
             "default_ipv6_ip_address": default_ipv6_ip_address,
             "default_ipv4_ip_address": default_ipv4_ip_address,
             "default_ipv6_netbox_id": default_ipv6_netbox_id,
