@@ -213,6 +213,21 @@ class NodeMeilisearchFactory(_NodeFactory):
     groups = [NodeGroup.MEILISEARCH]
 
 
+class NodeDockerFactory(_NodeFactory):
+    """Factory for specific object."""
+
+    class Meta:
+        """Settings."""
+
+        exclude = ("cluster",)
+
+    cluster = factory.SubFactory(
+        "cyberfusion.ClusterSupport.tests_factories.clusters.ClusterWebFactory"
+    )
+    cluster_id = factory.SelfAttribute("cluster.id")
+    groups = [NodeGroup.DOCKER]
+
+
 class NodeNewRelicFactory(_NodeFactory):
     """Factory for specific object."""
 
